My Project: src/c/so3_about.c File Reference

My Project

Functions
so3_about.c File Reference
`#include <stdio.h>`

Go to the source code of this file.

## Functions
int | main (int argc, char *argv[])

## Detailed Description

Print information about the SO3 package, including version and build numbers.

Usage: so3_about

Author
  Martin Büttner
  Jason McEwen

Definition in file so3_about.c.

## Function Documentation

## ◆ main()

int main | ( | int | argc,
|  | char * | argv[]
| ) |  |

Definition at line 18 of file so3_about.c.